EXPORTS
	??0TSourceSink@CMMFFindAndOpenController@@QAE@VTUid@@ABVRFile@@@Z @ 1 NONAME ; CMMFFindAndOpenController::TSourceSink::TSourceSink(class TUid, class RFile const &)
	??0TSourceSink@CMMFFindAndOpenController@@QAE@VTUid@@ABVTDesC8@@@Z @ 2 NONAME ; CMMFFindAndOpenController::TSourceSink::TSourceSink(class TUid, class TDesC8 const &)
	?CallBack@CMMFMdaObjectStateChangeObserverCallback@@QAEXPAVCBase@@HHH@Z @ 3 NONAME ; void CMMFMdaObjectStateChangeObserverCallback::CallBack(class CBase *, int, int, int)
	?Close@CMMFFindAndOpenController@@QAEXXZ @ 4 NONAME ; void CMMFFindAndOpenController::Close(void)
	?Configure@CMMFFindAndOpenController@@QAEXVTUid@@VTMMFPrioritySettings@@W4TMediaIdMatchType@CMMFPluginSelectionParameters@@@Z @ 5 NONAME ; void CMMFFindAndOpenController::Configure(class TUid, class TMMFPrioritySettings, enum CMMFPluginSelectionParameters::TMediaIdMatchType)
	?ConfigureController@CMMFFindAndOpenController@@QAEXAAVRMMFController@@AAVCMMFControllerEventMonitor@@W4TControllerMode@1@@Z @ 6 NONAME ; void CMMFFindAndOpenController::ConfigureController(class RMMFController &, class CMMFControllerEventMonitor &, enum CMMFFindAndOpenController::TControllerMode)
	?ConfigureSecondaryController@CMMFFindAndOpenController@@QAEXAAVRMMFController@@AAVCMMFControllerEventMonitor@@W4TControllerMode@1@@Z @ 7 NONAME ; void CMMFFindAndOpenController::ConfigureSecondaryController(class RMMFController &, class CMMFControllerEventMonitor &, enum CMMFFindAndOpenController::TControllerMode)
	?ConfigureSecondarySourceSink@CMMFFindAndOpenController@@QAEXVTSourceSink@1@0@Z @ 8 NONAME ; void CMMFFindAndOpenController::ConfigureSecondarySourceSink(class CMMFFindAndOpenController::TSourceSink, class CMMFFindAndOpenController::TSourceSink)
	?ConfigureSourceSink@CMMFFindAndOpenController@@QAEXABVTMMSource@@VTSourceSink@1@@Z @ 9 NONAME ; void CMMFFindAndOpenController::ConfigureSourceSink(class TMMSource const &, class CMMFFindAndOpenController::TSourceSink)
	?ConfigureSourceSink@CMMFFindAndOpenController@@QAEXVTSourceSink@1@0@Z @ 10 NONAME ; void CMMFFindAndOpenController::ConfigureSourceSink(class CMMFFindAndOpenController::TSourceSink, class CMMFFindAndOpenController::TSourceSink)
	?ConvertMdaCodecToFourCC@CMMFClientUtility@@SA?AVTFourCC@@AAVTMdaPackage@@@Z @ 11 NONAME ; class TFourCC CMMFClientUtility::ConvertMdaCodecToFourCC(class TMdaPackage &)
	?ConvertMdaFormatUidToECOMRead@CMMFClientUtility@@SA?AVTUid@@V2@@Z @ 12 NONAME ; class TUid CMMFClientUtility::ConvertMdaFormatUidToECOMRead(class TUid)
	?ConvertMdaFormatUidToECOMWrite@CMMFClientUtility@@SA?AVTUid@@V2@@Z @ 13 NONAME ; class TUid CMMFClientUtility::ConvertMdaFormatUidToECOMWrite(class TUid)
	?GetConfigDescriptor@CMMFFindAndOpenController@@SA?AV?$TPckgBuf@VTMMFDescriptorParams@@@@ABVTDesC8@@@Z @ 14 NONAME ; class TPckgBuf<class TMMFDescriptorParams> CMMFFindAndOpenController::GetConfigDescriptor(class TDesC8 const &)
	?GetConfigFile@CMMFFindAndOpenController@@SA?AV?$TPckgBuf@VTMMFFileParams@@@@ABVTDesC16@@@Z @ 15 NONAME ; class TPckgBuf<class TMMFFileParams> CMMFFindAndOpenController::GetConfigFile(class TDesC16 const &)
	?GetConfigUrlL@CMMFFindAndOpenController@@SAXAAPAVCBufFlat@@ABVTDesC16@@H@Z @ 16 NONAME ; void CMMFFindAndOpenController::GetConfigUrlL(class CBufFlat * &, class TDesC16 const &, int)
	?GetFileExtensionL@CMMFClientUtility@@SAPAVHBufC8@@ABVTDesC16@@@Z @ 17 NONAME ; class HBufC8 * CMMFClientUtility::GetFileExtensionL(class TDesC16 const &)
	?GetFileHeaderData@CMMFClientUtility@@SAHABVTDesC16@@AAVTDes8@@H@Z @ 18 NONAME ; int CMMFClientUtility::GetFileHeaderData(class TDesC16 const &, class TDes8 &, int)
	?NewL@CMMFFindAndOpenController@@SAPAV1@AAVMMMFFindAndOpenControllerObserver@@@Z @ 19 NONAME ; class CMMFFindAndOpenController * CMMFFindAndOpenController::NewL(class MMMFFindAndOpenControllerObserver &)
	?NewL@CMMFMdaObjectStateChangeObserverCallback@@SAPAV1@AAVMMdaObjectStateChangeObserver@@@Z @ 20 NONAME ; class CMMFMdaObjectStateChangeObserverCallback * CMMFMdaObjectStateChangeObserverCallback::NewL(class MMdaObjectStateChangeObserver &)
	?NewL@CMMFileSourceSink@@SAPAV1@VTUid@@ABVRFile@@@Z @ 21 NONAME ; class CMMFileSourceSink * CMMFileSourceSink::NewL(class TUid, class RFile const &)
	?NewL@CMMFileSourceSink@@SAPAV1@VTUid@@ABVTMMSource@@@Z @ 22 NONAME ; class CMMFileSourceSink * CMMFileSourceSink::NewL(class TUid, class TMMSource const &)
	?NewL@CMMSourceSink@@SAPAV1@VTUid@@ABVTDesC8@@@Z @ 23 NONAME ; class CMMSourceSink * CMMSourceSink::NewL(class TUid, class TDesC8 const &)
	?NewLC@CMMFileSourceSink@@SAPAV1@VTUid@@ABVRFile@@@Z @ 24 NONAME ; class CMMFileSourceSink * CMMFileSourceSink::NewLC(class TUid, class RFile const &)
	?NewLC@CMMFileSourceSink@@SAPAV1@VTUid@@ABVTMMSource@@@Z @ 25 NONAME ; class CMMFileSourceSink * CMMFileSourceSink::NewLC(class TUid, class TMMSource const &)
	?NewLC@CMMSourceSink@@SAPAV1@VTUid@@ABVTDesC8@@@Z @ 26 NONAME ; class CMMSourceSink * CMMSourceSink::NewLC(class TUid, class TDesC8 const &)
	?OpenByControllerUid@CMMFFindAndOpenController@@QAEXVTUid@@0@Z @ 27 NONAME ; void CMMFFindAndOpenController::OpenByControllerUid(class TUid, class TUid)
	?OpenByDescriptor@CMMFFindAndOpenController@@QAEXABVTDesC8@@@Z @ 28 NONAME ; void CMMFFindAndOpenController::OpenByDescriptor(class TDesC8 const &)
	?OpenByFileSource@CMMFFindAndOpenController@@QAEXABVTMMSource@@ABVTDesC16@@@Z @ 29 NONAME ; void CMMFFindAndOpenController::OpenByFileSource(class TMMSource const &, class TDesC16 const &)
	?OpenByFormatUid@CMMFFindAndOpenController@@QAEXVTUid@@0@Z @ 30 NONAME ; void CMMFFindAndOpenController::OpenByFormatUid(class TUid, class TUid)
	?OpenByUrl@CMMFFindAndOpenController@@QAEXABVTDesC16@@HABVTDesC8@@@Z @ 31 NONAME ; void CMMFFindAndOpenController::OpenByUrl(class TDesC16 const &, int, class TDesC8 const &)
	?ReOpen@CMMFFindAndOpenController@@QAEXXZ @ 32 NONAME ; void CMMFFindAndOpenController::ReOpen(void)
	?EvaluateIntentL@CMMFileSourceSink@@QAEXW4TIntent@ContentAccess@@@Z @ 33 NONAME ; void CMMFileSourceSink::EvaluateIntentL(enum ContentAccess::TIntent)
	?UseSharedHeap@CMMFFindAndOpenController@@QAEXXZ @ 34 NONAME ; void CMMFFindAndOpenController::UseSharedHeap(void)
	?CloseConfig@CMMFFindAndOpenController@@QAEXXZ @ 35 NONAME ; void CMMFFindAndOpenController::CloseConfig(void)
	?SetInitScreenNumber@CMMFFindAndOpenController@@QAEXHPAVRMMFVideoSetInitScreenCustomCommands@@@Z @ 36 NONAME ; void CMMFFindAndOpenController::SetInitScreenNumber(int, class RMMFVideoSetInitScreenCustomCommands *)
	

